@@ -2,15 +2,18 @@ from typing import Optional
 
 
 def _login_request_info(username: str, password: str, scope: Optional[str] = None) -> dict:
-    return {
-        "url": f"https://auth.algoralabs.com/auth/realms/production/protocol/openid-connect/token",
-        "data": {
+    data = {
             "client_id": "algora-api",
-            "scope": scope,
             "grant_type": "password",
             "username": username,
             "password": password
         }
+    if scope is not None:
+        data.update({'scope': scope})
+
+    return {
+        "url": f"https://auth.algoralabs.com/auth/realms/production/protocol/openid-connect/token",
+        'data': data
     }
 
 
